기술 자료

Furioos API


Furioos API


Furioos API

Introduction

Key features of Furioos API: + Manage the creation, editing, sharing and deletion of your applications + Get information about your applications
Note: the reservations feature is not yet available through our API Services.

Notes about the Beta version

During the Beta period, the information in this document is not guaranteed to be up-to-date and may change without notice.

How to get started

Create an API Key

Upload an application

Create a share link for you application

Download OpenAPI specification:

Returns all active applications with the information of applications and application binaries.


Returns all active applications of the connected user
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applications"

Response example

[ { "_id": "7dQDCuGxa86n6m7Ad", "name": "Name of my application", "description": "Description of the application", "parameters": { "quality": 3, "touchConvert": false }, "tags": [], "viewCount": 4, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "applicationBinaries": [ { "_id": "Jq4rua5D8KWDnSWfB", "applicationID": "7dQDCuGxa86n6m7Ad", "version": "string", "archive": "myApp.zip", "exe": "folder/myApp.exe", "exeList": [ "folder/myApp.exe", "folder/myApp.bat" ], "size": 4837261812, "checksum": 247289271285, "thumbnailUrl": "https://storage.googleapis.com/Ayzo16uik726fdbx/qYSxd492qqxXesXLL/6Nc3pTJoMXWW3nPRp/thumbnail.image", "uploaded": true, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "computeTypeName": "Standard" } ] }]

Creates a new application


Creates a new application.
Returns the information of the new application and the application binary.
Warning - You must call the POST route upload to send your archive
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Request body for "{title}"

Media Type:
multipart/form-data

name

string
필수
Name of the application

description

string
필수
Description of the application

mainExe

string
필수
example: folder/myfile.exe
Path of exe file

thumbnail

string
필수
Application thumbnail. Must be an image file

quality

integer
Quality type. Must be between 0 and 4.
0- 360p/30fps
1- 480p/30fps
2- 720p/30fps
3- 1080p/60fps -- default
4- Auto

computeTypeName

string
Compute type name. The value must be :
-Standard -- default
-High
-Extreme

touchConvert

boolean
Convert touch event to mouse event. false value by default

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X POST \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: multipart/form-data" \ -d '{"name":"Name of my application","description":"Description of the application","mainExe":"folder/myfile.exe","thumbnail":"string","quality":0,"computeTypeName":"string","touchConvert":true}' \ "https://api.furioos.com/v1/applications"

Response example

{ "application": { "_id": "7dQDCuGxa86n6m7Ad", "name": "Name of my application", "description": "Description of the application", "parameters": { "quality": 3, "touchConvert": false }, "tags": [], "viewCount": 4, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active" }, "applicationBinary": { "_id": "Jq4rua5D8KWDnSWfB", "applicationID": "7dQDCuGxa86n6m7Ad", "version": "string", "archive": "myApp.zip", "exe": "folder/myApp.exe", "exeList": [ "folder/myApp.exe", "folder/myApp.bat" ], "size": 4837261812, "checksum": 247289271285, "thumbnailUrl": "https://storage.googleapis.com/Ayzo16uik726fdbx/qYSxd492qqxXesXLL/6Nc3pTJoMXWW3nPRp/thumbnail.image", "uploaded": true, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "computeTypeName": "Standard" }}

Returns all applications that are being uploaded with this token


Returns all applications that are being uploaded with this token
The information remain present for 60 minutes
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applications/progress"

Response example

[ { "_id": "nsRzZzQBQ4ZB9tbYm", "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "filename": "filename.zip", "addedAt": "2021-05-20T10:45:00.169Z", "status": "In progress", "progress": 55, "byteRead": 11193456, "completeAt": "2021-05-20T10:51:08.068Z" }]

Returns the information of the application and application binary


Returns the information of the application and application binary
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationID

string
필수
ID of the application

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applications/{applicationID}"

Response example

{ "_id": "7dQDCuGxa86n6m7Ad", "name": "Name of my application", "description": "Description of the application", "parameters": { "quality": 3, "touchConvert": false }, "tags": [], "viewCount": 4, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "applicationBinaries": [ { "_id": "Jq4rua5D8KWDnSWfB", "applicationID": "7dQDCuGxa86n6m7Ad", "version": "string", "archive": "myApp.zip", "exe": "folder/myApp.exe", "exeList": [ "folder/myApp.exe", "folder/myApp.bat" ], "size": 4837261812, "checksum": 247289271285, "thumbnailUrl": "https://storage.googleapis.com/Ayzo16uik726fdbx/qYSxd492qqxXesXLL/6Nc3pTJoMXWW3nPRp/thumbnail.image", "uploaded": true, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "computeTypeName": "Standard" } ]}

Update an application


Update an application
Returns the information updated of the application and the application binary
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationID

string
필수
ID of the application

Request body for "{title}"

Media Type:
multipart/form-data

name

string
필수
Name of the application

description

string
필수
Description of the application

mainExe

string
필수
example: folder/myfile.exe
Path of exe file

thumbnail

string
필수
Application thumbnail. Must be an image file

quality

integer
Quality type. Must be between 0 and 4.
0- 360p/30fps
1- 480p/30fps
2- 720p/30fps
3- 1080p/60fps -- default
4- Auto

computeTypeName

string
Compute type name. The value must be :
-Standard -- default
-High
-Extreme

touchConvert

boolean
Convert touch event to mouse event. false value by default

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X PUT \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: multipart/form-data" \ -d '{"name":"Name of my application","description":"Description of the application","mainExe":"folder/myfile.exe","thumbnail":"string","quality":0,"computeTypeName":"string","touchConvert":true}' \ "https://api.furioos.com/v1/applications/{applicationID}"

Response example

{ "application": { "_id": "7dQDCuGxa86n6m7Ad", "name": "Name of my application", "description": "Description of the application", "parameters": { "quality": 3, "touchConvert": false }, "tags": [], "viewCount": 4, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active" }, "applicationBinary": { "_id": "Jq4rua5D8KWDnSWfB", "applicationID": "7dQDCuGxa86n6m7Ad", "version": "string", "archive": "myApp.zip", "exe": "folder/myApp.exe", "exeList": [ "folder/myApp.exe", "folder/myApp.bat" ], "size": 4837261812, "checksum": 247289271285, "thumbnailUrl": "https://storage.googleapis.com/Ayzo16uik726fdbx/qYSxd492qqxXesXLL/6Nc3pTJoMXWW3nPRp/thumbnail.image", "uploaded": true, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "computeTypeName": "Standard" }}

Delete an application and its application binaries


Delete an application and its applications binaries
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationID

string
필수
ID of the application

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X DELETE \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applications/{applicationID}"

Response example

{ "_id": "7GuNM6CpwX9o2fu7Y"}

Returns the detail of the application that are being uploaded with this token


Returns the detail of the application that are being uploaded
The information remain present for 60 minutes
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application binary

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applications/progress/{applicationBinaryID}"

Response example

{ "_id": "nsRzZzQBQ4ZB9tbYm", "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "filename": "filename.zip", "addedAt": "2021-05-20T10:45:00.169Z", "status": "In progress", "progress": 55, "byteRead": 11193456, "completeAt": "2021-05-20T10:51:08.068Z"}

Returns all active application binaries


Returns all active application binaries of the connected user
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries"

Response example

[ { "_id": "Jq4rua5D8KWDnSWfB", "applicationID": "7dQDCuGxa86n6m7Ad", "version": "string", "archive": "myApp.zip", "exe": "folder/myApp.exe", "exeList": [ "folder/myApp.exe", "folder/myApp.bat" ], "size": 4837261812, "checksum": 247289271285, "thumbnailUrl": "https://storage.googleapis.com/Ayzo16uik726fdbx/qYSxd492qqxXesXLL/6Nc3pTJoMXWW3nPRp/thumbnail.image", "uploaded": true, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "computeTypeName": "Standard" }]

Returns all active shares


Returns all active shares of the connected user
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/shares"

Response example

[ { "_id": "YYjrWfBER9thowoEM", "type": 1, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "autorun": false, "hasPassword": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "linkUrl": "https://portal.furioos.com/share/455.128" }]

Returns the share detail by ID


Returns the share detail by ID of the connected user
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

shareID

string
필수
ID of the share

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/shares/{shareID}"

Response example

{ "_id": "YYjrWfBER9thowoEM", "type": 1, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "autorun": false, "hasPassword": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "linkUrl": "https://portal.furioos.com/share/455.128"}

Delete a share by ID


Delete a share by ID
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

shareID

string
필수
ID of the share

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X DELETE \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/shares/{shareID}"

Response example

{ "_id": "7GuNM6CpwX9o2fu7Y"}

Returns the application binary information by ID


Returns the application binary information by ID
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application binary

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}"

Response example

{ "_id": "Jq4rua5D8KWDnSWfB", "applicationID": "7dQDCuGxa86n6m7Ad", "version": "string", "archive": "myApp.zip", "exe": "folder/myApp.exe", "exeList": [ "folder/myApp.exe", "folder/myApp.bat" ], "size": 4837261812, "checksum": 247289271285, "thumbnailUrl": "https://storage.googleapis.com/Ayzo16uik726fdbx/qYSxd492qqxXesXLL/6Nc3pTJoMXWW3nPRp/thumbnail.image", "uploaded": true, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "computeTypeName": "Standard"}

Returns all active shares of the application binary


Returns all active shares of the application binary
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application binary

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares"

Response example

[ { "_id": "YYjrWfBER9thowoEM", "type": 1, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "autorun": false, "hasPassword": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "linkUrl": "https://portal.furioos.com/share/455.128" }]

Returns all active shares links of the application binary
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application binary

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/links"

Response example

[ { "_id": "YYjrWfBER9thowoEM", "type": 1, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "autorun": false, "hasPassword": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "linkUrl": "https://portal.furioos.com/share/455.128" }]

Creates a share link for the application binary


Creates a share link for the application binary and returns the information
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application

Request body for "{title}"

Media Type:
application/json

autoRun

boolean
Auto run the session

password

string
Password protection for your application

compute

integer
example: 3600
Monthly usage quota (seconds)

maxDuration

integer
example: 600
Maximum session time (seconds)

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X POST \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: application/x-www-form-urlencoded" \ -d '{"autoRun":false,"password":"string","compute":3600,"maxDuration":600}' \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/links"

Response example

{ "_id": "YYjrWfBER9thowoEM", "type": 1, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "autorun": false, "hasPassword": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "linkUrl": "https://portal.furioos.com/share/455.128"}

Returns all active shares embed of the application binary


Returns all active shares embed of the application binary
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application binary

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/embed"

Response example

[ { "_id": "YYjrWfBER9thowoEM", "type": 2, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "hasPassword": false, "whiteLabel": false, "hideTitle": false, "hideToolbar": false, "autorun": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "embedUrl": "https://portal.furioos.com/embed/455.128", "iframe": "<iframe src=\"https://portal.furioos.com/embed/455.128\" width=\"560\" height=\"315\" allowfullscreen=\"true\"></iframe>" }]

Creates an embed share for the application binary


Creates an embed share for the application binary and returns the information
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application

Request body for "{title}"

Media Type:
application/json

autoRun

boolean
Auto run the session

whiteLabel

boolean
Enable white label if true

hideTitle

boolean
Hide title if true

hideToolbar

boolean
Hide toolbar if true

password

string
Password protection for your application

compute

integer
example: 3600
Monthly usage quota (seconds)

maxDuration

integer
example: 600
Maximum session time (seconds)

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X POST \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: application/x-www-form-urlencoded" \ -d '{"autoRun":false,"whiteLabel":false,"hideTitle":false,"hideToolbar":false,"password":"string","compute":3600,"maxDuration":600}' \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/embed"

Response example

{ "_id": "YYjrWfBER9thowoEM", "type": 2, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "hasPassword": false, "whiteLabel": false, "hideTitle": false, "hideToolbar": false, "autorun": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "embedUrl": "https://portal.furioos.com/embed/455.128", "iframe": "<iframe src=\"https://portal.furioos.com/embed/455.128\" width=\"560\" height=\"315\" allowfullscreen=\"true\"></iframe>"}

Returns all active shares SDK of the application binary


Returns all active shares SDK of the application binary
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application binary

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X GET \ -H "Authorization: Bearer <YOUR_TOKEN>" \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/sdk"

Response example

[ { "_id": "YYjrWfBER9thowoEM", "type": 3, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "websiteUrl": "https://myWebsite.com", "linkID": 455.128, "sharedAt": "2021-05-26T08:54:20.284Z", "hasPassword": false, "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" } }]

Creates a share SDK for the application binary


Creates a share SDK for the application binary and returns the information of the share SDK
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application

Request body for "{title}"

Media Type:
application/json

compute

integer
example: 3600
Monthly usage quota (seconds)

maxDuration

integer
example: 600
Maximum session time (seconds)

websiteUrl

string
example: https://myWebsite.com
Specify the URL of the website where Furioos SDK will be used (HTTPS required)

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X POST \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: application/x-www-form-urlencoded" \ -d '{"compute":3600,"maxDuration":600,"websiteUrl":"https://myWebsite.com"}' \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/sdk"

Response example

{ "_id": "YYjrWfBER9thowoEM", "type": 3, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "websiteUrl": "https://myWebsite.com", "linkID": 455.128, "sharedAt": "2021-05-26T08:54:20.284Z", "hasPassword": false, "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }}

Upload a zip file


Upload your application's zip file.
Returns the information of the new application and the application binary
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application

Request body for "{title}"

Media Type:
multipart/form-data

file

string
필수
example: users/folder/myapp.zip
Local path of the application archive. Must be a zip file

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X POST \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: multipart/form-data" \ -d '{"file":"users/folder/myapp.zip"}' \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/upload"

Response example

{ "_id": "Jq4rua5D8KWDnSWfB", "applicationID": "7dQDCuGxa86n6m7Ad", "version": "string", "archive": "myApp.zip", "exe": "folder/myApp.exe", "exeList": [ "folder/myApp.exe", "folder/myApp.bat" ], "size": 4837261812, "checksum": 247289271285, "thumbnailUrl": "https://storage.googleapis.com/Ayzo16uik726fdbx/qYSxd492qqxXesXLL/6Nc3pTJoMXWW3nPRp/thumbnail.image", "uploaded": true, "updateAt": "2021-05-20T13:51:08.068Z", "createdAt": "2021-05-20T10:45:00.169Z", "status": "active", "computeTypeName": "Standard"}

Update a share link of the application binary


Update a share link of the application binary and returns the information updated
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application

shareID

string
필수
ID of share link

Request body for "{title}"

Media Type:
application/json

autoRun

boolean
Auto run the session

password

string
Password protection for your application

compute

integer
example: 3600
Monthly usage quota (seconds)

maxDuration

integer
example: 600
Maximum session time (seconds)

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X PUT \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: application/x-www-form-urlencoded" \ -d '{"autoRun":false,"password":"string","compute":3600,"maxDuration":600}' \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/links/{shareID}"

Response example

{ "_id": "YYjrWfBER9thowoEM", "type": 1, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "autorun": false, "hasPassword": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "linkUrl": "https://portal.furioos.com/share/455.128"}

Update a share embed of the application binary


Update a share embed of the application binary and returns the information updated
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application

shareID

string
필수
ID of share link

Request body for "{title}"

Media Type:
application/json

autoRun

boolean
Auto run the session

whiteLabel

boolean
Enable white label if true

hideTitle

boolean
Hide title if true

hideToolbar

boolean
Hide toolbar if true

password

string
Password protection for your application

compute

integer
example: 3600
Monthly usage quota (seconds)

maxDuration

integer
example: 600
Maximum session time (seconds)

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X PUT \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: application/x-www-form-urlencoded" \ -d '{"autoRun":false,"whiteLabel":false,"hideTitle":false,"hideToolbar":false,"password":"string","compute":3600,"maxDuration":600}' \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/embed/{shareID}"

Response example

{ "_id": "YYjrWfBER9thowoEM", "type": 2, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "linkID": 455.128, "hasPassword": false, "whiteLabel": false, "hideTitle": false, "hideToolbar": false, "autorun": false, "sharedAt": "2021-05-26T08:54:20.284Z", "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }, "embedUrl": "https://portal.furioos.com/embed/455.128", "iframe": "<iframe src=\"https://portal.furioos.com/embed/455.128\" width=\"560\" height=\"315\" allowfullscreen=\"true\"></iframe>"}

Update a share SDK of the application binary


Update a share SDK of the application binary and returns the information updated
Authorizations
bearerAuth
HTTP: bearerAuth
HTTP Authorization Scheme: bearer

Path parameters for "{title}"

applicationBinaryID

string
필수
ID of the application

shareID

string
필수
ID of share link

Request body for "{title}"

Media Type:
application/json

compute

integer
example: 3600
Monthly usage quota (seconds)

maxDuration

integer
example: 600
Maximum session time (seconds)

websiteUrl

string
example: https://myWebsite.com
Specify the URL of the website where Furioos SDK will be used (HTTPS required)

HTTP response status codes for "{title}":

Code samples for "{title}":

Request example

curl -X PUT \ -H "Authorization: Bearer <YOUR_TOKEN>" \ -H "Content-Type: application/x-www-form-urlencoded" \ -d '{"compute":3600,"maxDuration":600,"websiteUrl":"https://myWebsite.com"}' \ "https://api.furioos.com/v1/applicationbinaries/{applicationBinaryID}/shares/sdk/{shareID}"

Response example

{ "_id": "YYjrWfBER9thowoEM", "type": 3, "applicationBinaryID": "7dQDCuGxa86n6m7Ad", "websiteUrl": "https://myWebsite.com", "linkID": 455.128, "sharedAt": "2021-05-26T08:54:20.284Z", "hasPassword": false, "status": "active", "quota": { "_id": "FXuqgG8LDRZSwWezi", "shareID": "YYjrWfBER9thowoEM", "compute": 3600, "usage": { "compute": 11446 }, "session": { "maxDuration": 600 }, "creatededAt": "2021-05-26T08:54:20.284Z", "refreshedAt": "2021-05-26T08:54:20.284Z", "status": "active" }}